@@ -26,9 +26,3 @@ class RevisionCreationDateFacet(facet.DateRangeFacet):
     __select__ = facet.DateRangeFacet.__select__ & is_instance('Revision')
     rtype = 'creation_date'
     order = 4
-
-class VFModificationDateFacet(facet.DateRangeFacet):
-    __regid__ = 'vcsfile.vf.cd'
-    __select__ = facet.DateRangeFacet.__select__ & is_instance('VersionedFile')
-    rtype = 'modification_date'
-    order = 4
